@@ -14,7 +14,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
     CreateOutpostOutputTypeDef,
@@ -46,18 +46,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class OutpostsClient:
+class OutpostsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        OutpostsClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#can_paginate)
         """
 
@@ -72,19 +79,25 @@ class OutpostsClient:
         Tags: Dict[str, str] = None
     ) -> CreateOutpostOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.create_outpost)
+        Creates an Outpost.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.create_outpost)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#create_outpost)
         """
 
     def delete_outpost(self, *, OutpostId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.delete_outpost)
+        Deletes the Outpost.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.delete_outpost)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#delete_outpost)
         """
 
     def delete_site(self, *, SiteId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.delete_site)
+        Deletes the site.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.delete_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#delete_site)
         """
 
@@ -96,13 +109,17 @@ class OutpostsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#generate_presigned_url)
         """
 
     def get_outpost(self, *, OutpostId: str) -> GetOutpostOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.get_outpost)
+        Gets information about the specified Outpost.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.get_outpost)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#get_outpost)
         """
 
@@ -110,7 +127,9 @@ class OutpostsClient:
         self, *, OutpostId: str, NextToken: str = None, MaxResults: int = None
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
+        Lists the instance types for the specified Outpost.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#get_outpost_instance_types)
         """
 
@@ -118,7 +137,9 @@ class OutpostsClient:
         self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListOutpostsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.list_outposts)
+        List the Outposts for your AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.list_outposts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#list_outposts)
         """
 
@@ -126,24 +147,32 @@ class OutpostsClient:
         self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListSitesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.list_sites)
+        Lists the sites for the specified AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.list_sites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#list_sites)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.list_tags_for_resource)
+        Lists the tags for the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#list_tags_for_resource)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.tag_resource)
+        Adds tags to the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/outposts.html#Outposts.Client.untag_resource)
+        Removes tags from the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/outposts.html#Outposts.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#untag_resource)
         """
